# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.10.3-v202502171101-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class DebugCacheBlockOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'blocks': 'list[CacheBlock]',
        'read_status': 'str'
    }

    attribute_map = {
        'blocks': 'blocks',
        'read_status': 'readStatus'
    }

    def __init__(self, blocks=None, read_status=None):
        """
        DebugCacheBlockOutputV1 - a model defined in Swagger
        """

        self._blocks = None
        self._read_status = None

        if blocks is not None:
          self.blocks = blocks
        if read_status is not None:
          self.read_status = read_status

    @property
    def blocks(self):
        """
        Gets the blocks of this DebugCacheBlockOutputV1.

        :return: The blocks of this DebugCacheBlockOutputV1.
        :rtype: list[CacheBlock]
        """
        return self._blocks

    @blocks.setter
    def blocks(self, blocks):
        """
        Sets the blocks of this DebugCacheBlockOutputV1.

        :param blocks: The blocks of this DebugCacheBlockOutputV1.
        :type: list[CacheBlock]
        """

        self._blocks = blocks

    @property
    def read_status(self):
        """
        Gets the read_status of this DebugCacheBlockOutputV1.

        :return: The read_status of this DebugCacheBlockOutputV1.
        :rtype: str
        """
        return self._read_status

    @read_status.setter
    def read_status(self, read_status):
        """
        Sets the read_status of this DebugCacheBlockOutputV1.

        :param read_status: The read_status of this DebugCacheBlockOutputV1.
        :type: str
        """
        allowed_values = ["PARTIAL", "COMPLETE", "UNRECOGNIZED"]
        if read_status not in allowed_values:
            raise ValueError(
                "Invalid value for `read_status` ({0}), must be one of {1}"
                .format(read_status, allowed_values)
            )

        self._read_status = read_status

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DebugCacheBlockOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
